%global sepol_ver 3.6
%global selinux_ver 3.6

Name:           setools
Version:        4.5.1
Release:        %mkrel 3
Summary:        Policy analysis tools for SELinux
Group:          System/Base
License:        GPLv2
URL:            https://github.com/SELinuxProject/setools/wiki
Source0:        https://github.com/SELinuxProject/setools/releases/download/%{version}/%{name}-%{version}.tar.bz2
Source1:        setools.pam
Source2:        apol.desktop
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  glibc-devel
BuildRequires:  git-core
BuildRequires:  libsepol-devel >= %{sepol_ver}, libsepol-static-devel >= %{sepol_ver}
BuildRequires:  swig
BuildRequires:  python3-cython
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  libselinux-devel

Requires:       %{name}-console = %{version}-%{release}
Requires:       %{name}-console-analyses = %{version}-%{release}
Requires:       %{name}-gui = %{version}-%{release}

%description
SETools is a collection of graphical tools, command-line tools, and
Python modules designed to facilitate SELinux policy analysis.

%package     console
Summary:     Policy analysis command-line tools for SELinux
License:     GPLv2
Group:       System/Base
Requires:    python3-setools = %{version}-%{release}
Requires:    libselinux >= %{selinux_ver}

%description console
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

This package includes the following console tools:

  sediff       Compare two policies to find differences.
  seinfo       List policy components.
  sesearch     Search rules (allow, type_transition, etc.)


%package     console-analyses
Summary:     Policy analysis command-line tools for SELinux
License:     GPLv2
Group:       System/Base
Requires:    python3-setools = %{version}-%{release}
Requires:    libselinux >= %{selinux_ver}
Requires:    python3-networkx

%description console-analyses
SETools is a collection of graphical tools, command-line tools, and
libraries designed to facilitate SELinux policy analysis.

This package includes the following console tools:

  sedta        Perform domain transition analyses.
  seinfoflow   Perform information flow analyses.


%package     -n python3-setools
Summary:     Policy analysis tools for SELinux  
Group:       System/Base
Obsoletes:   setools-libs < 4.0.0
Recommends:  libselinux-python3
%{?python_provide:%python_provide python3-setools}
Requires:    python3-setuptools

%description -n python3-setools
SETools is a collection of graphical tools, command-line tools, and
Python 3 modules designed to facilitate SELinux policy analysis.


%package     gui
Summary:     Policy analysis graphical tools for SELinux
Group:       System/Base
Requires:    python3-setools = %{version}-%{release}
Requires:    python3-qt6
Requires:    python3-pyqt6-sip
Requires:    python3-networkx

%description gui
SETools is a collection of graphical tools, command-line tools, and
Python modules designed to facilitate SELinux policy analysis.


%prep
%autosetup -p1 -n %{name}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel


%install
%pyproject_install

%check
%if %{?_with_check:1}%{!?_with_check:0}
# dnf install python3-pytest python3-pytest-qt
%pytest
%endif


%files

%files console
%license COPYING.GPL
%{_bindir}/sechecker
%{_bindir}/sediff
%{_bindir}/seinfo
%{_bindir}/sesearch
%{_mandir}/man1/sechecker*
%{_mandir}/man1/sediff*
%{_mandir}/man1/seinfo*
%{_mandir}/man1/sesearch*
%{_mandir}/ru/man1/sediff*
%{_mandir}/ru/man1/seinfo*
%{_mandir}/ru/man1/sesearch*

%files console-analyses
%license COPYING.GPL
%{_bindir}/sedta
%{_bindir}/seinfoflow
%{_mandir}/man1/sedta*
%{_mandir}/man1/seinfoflow*
%{_mandir}/ru/man1/sedta*
%{_mandir}/ru/man1/seinfoflow*

%files -n python3-setools
%license COPYING COPYING.LGPL
%{python3_sitearch}/setools
%{python3_sitearch}/setools-*

%files gui
%license COPYING.GPL
%{_bindir}/apol
%{python3_sitearch}/setoolsgui
%{_mandir}/man1/apol*
%{_mandir}/ru/man1/apol*



%changelog
* Wed Jul 02 2025 umeabot <umeabot> 4.5.1-3.mga10
+ Revision: 2243438
- Mageia 10 Mass Rebuild

* Sat Mar 08 2025 daviddavid <daviddavid> 4.5.1-2.mga10
+ Revision: 2161893
- fix dependencies

* Tue Mar 04 2025 daviddavid <daviddavid> 4.5.1-1.mga10
+ Revision: 2160793
- new version: 4.5.1
+ wally <wally>
- rebuild for python3.13

* Thu Dec 28 2023 daviddavid <daviddavid> 4.4.0-0.2.20210121git16c0696.4.mga10
+ Revision: 2022788
- switch to cython 0.29.x
- rebuild for py3.12

* Mon Apr 04 2022 umeabot <umeabot> 4.4.0-0.2.20210121git16c0696.3.mga9
+ Revision: 1842955
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 4.4.0-0.2.20210121git16c0696.2.mga9
+ Revision: 1778518
- Rebuild for python-3.10

* Fri Jan 29 2021 neoclust <neoclust> 4.4.0-0.2.20210121git16c0696.1.mga9
+ Revision: 1673970
- New version 4.4.0

* Wed Jan 27 2021 neoclust <neoclust> 3.3.8-18.mga8
+ Revision: 1673756
- Fix build against swig 4.0.2
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 3.3.8-16.mga7
+ Revision: 1301003
- Mageia 7 Mass Rebuild

* Wed Mar 02 2016 pterjan <pterjan> 3.3.8-15.mga6
+ Revision: 981853
- Finish fixing build
- Fix underlinking
- Sync patches with fedora + backport upstream swig3 patch
+ spuhler <spuhler>
- updated SWIG-3.0.0.patch file
- added tclass.patch file
- added Patch0: tclass.patch
- added patch per upstream commit f1e5b20
- updated %%define sepol_ver 2.4 +%%define selinux_ver 2.4 per upstream req.
+ tv <tv>
- update d/l URL
- drop some old obsoletes
- drop support for python bindings (like FC)
- remove java bindings (not supported in FC too)
- run aclocal + automake too
- fixup expected version of SWIG
- fix warnings about doble summary & group
- kill sediffx (no more in FC)
- actually apply patch 1 (was in SVN for a long time...)
--Cette ligne, et les suivantesac ci-dessous, seront ignorées--
  M    SPECS/setools.spec
- sync patches with FC
- drop unapplied patch 7

* Sat Oct 03 2015 spuhler <spuhler> 3.3.8-13.mga6
+ Revision: 885934
- rebuild for tcl

* Fri Aug 28 2015 spuhler <spuhler> 3.3.8-12.mga6
+ Revision: 870383
- use with new gcj-5.2
- rebuild with new gcj-5.2.1

* Fri Oct 31 2014 spuhler <spuhler> 3.3.8-11.mga5
+ Revision: 794974
- Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 3.3.8-10.mga5
+ Revision: 746408
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.3.8-9.mga5
+ Revision: 730117
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.3.8-8.mga5
+ Revision: 689118
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 spuhler <spuhler> 3.3.8-7.mga5
+ Revision: 669575
- added BuildRequires: pkgconfig(libgcj-4.9)
+ luigiwalser <luigiwalser>
- drop gcj support

* Tue Jul 29 2014 spuhler <spuhler> 3.3.8-6.mga5
+ Revision: 657848
- upgraded swig selinux and python version
- added patches from Fedora

* Sat May 31 2014 pterjan <pterjan> 3.3.8-5.mga5
+ Revision: 629147
- Rebuild for new Python

* Wed Mar 26 2014 wally <wally> 3.3.8-4.mga5
+ Revision: 608769
- add patch to fix build with new swig

* Tue Oct 22 2013 umeabot <umeabot> 3.3.8-3.mga4
+ Revision: 544497
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.3.8-2.mga4
+ Revision: 499855
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Feb 27 2013 spuhler <spuhler> 3.3.8-1.mga3
+ Revision: 400567
- upgraded to 3.3.8
  Changes since 3.3.7
  o Fix compile errors on new parameter in libsepol role_set_expand().
  o Fix file type drop down list for open/close Apol query.
  o Add python bindings for seinfo and sesearch by Dan Walsh.
  o seinfo exits with an error status by Dan Walsh.
  o Support for named file transition rules by Dan Walsh.
  o Add support for default types in sesearch by Steve Lawrence.
  o Man page updates for seinfo, seaudit, and sediff by Dan Walsh.
  o Fix bug preventing seaudit from starting by Jake Lightner.
  Updated changed source location
  dropped patches not required anymore
   o python.patch
   o setup_py-prefix.patch
   o swig-2x.patch
   o 3.3.6-libsepol.patch
  this upgrade provides header files needed for policycoreutils
   o they were inserted before with an ugly patch that did not build on mageia

* Mon Jan 14 2013 umeabot <umeabot> 3.3.7-8.mga3
+ Revision: 381946
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 cjw <cjw> 3.3.7-7.mga3
+ Revision: 344529
- fix build with automake 1.13
+ spuhler <spuhler>
- rebuild against newest sepol version

* Mon Sep 17 2012 fwang <fwang> 3.3.7-5.mga3
+ Revision: 294825
- cleanup spec

* Mon Sep 17 2012 fwang <fwang> 3.3.7-4.mga3
+ Revision: 294800
- move define to head
- bump rel
- update file list
- obsoletes old libname
- split out libs

* Mon Sep 17 2012 spuhler <spuhler> 3.3.7-3.mga3
+ Revision: 294662
- used %%mklibname for the lib
  bumped rel

* Mon Sep 10 2012 spuhler <spuhler> 3.3.7-2.mga3
+ Revision: 292003
- cleaned up spec file
  bumped release

* Sat Sep 08 2012 spuhler <spuhler> 3.3.7-1.mga3
+ Revision: 290440
- first release
- imported package setools


* Thu Jan 08 2009 Jérôme Soyer <saispo@mandriva.org> 3.3.5-2mdv2009.1
+ Revision: 327107
- Rebuild for new python
- Rebuild for new python

  + Michael Scherer <misc@mandriva.org>
    - do not harcode python version needed

* Sun Oct 19 2008 David Walluck <walluck@mandriva.org> 3.3.5-1mdv2009.1
+ Revision: 295378
- add new sources
- 3.3.5
- build with java, not gcj
- fix linking
- 3.3.4

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon Apr 21 2008 David Walluck <walluck@mandriva.org> 3.3.3-1mdv2009.0
+ Revision: 196068
- 3.3.3
- fix consolehelper symlink

* Mon Jan 07 2008 David Walluck <walluck@mandriva.org> 3.3.2-3mdv2008.1
+ Revision: 146178
- fix devel Requires

* Tue Jan 01 2008 David Walluck <walluck@mandriva.org> 3.3.2-2mdv2008.1
+ Revision: 140006
- fix sqlite BuildRequires
- fix sepol BuildRequires
- add BuildRequires for python
- spec cleanup
- fix python macros
- spec cleanup
- import setools


* Wed Nov 28 2007 Chris Pebenito <cpebenito@tresys.com> 3.3.2-1.fc9
- Update for 3.3.2.

* Thu Oct 18 2007 Chris PeBenito <cpebenito@tresys.com> 3.3.1-7.fc8
- Rebuild to fix ppc64 issue.

* Wed Oct 17 2007 Chris PeBenito <cpebenito@tresys.com> 3.3.1-6.fc8
- Update for 3.3.1.

* Tue Aug 28 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 3.2-4
- Rebuild for selinux ppc32 issue.

* Fri Jul 20 2007 Dan Walsh <dwalsh@redhat.com> 3.2-3
- Move to Tresys spec file

* Wed Jun 13 2007 Dan Walsh <dwalsh@redhat.com> 3.2-2
- Bump for rebuild

* Mon Apr 30 2007 Dan Walsh <dwalsh@redhat.com> 3.2-1
- Start shipping the rest of the setools command line apps

* Wed Apr 25 2007 Jason Tang <jtang@tresys.com> 3.2-0
- update to SETools 3.2 release

* Mon Feb 02 2007 Jason Tang <jtang@tresys.com> 3.1-1
- update to SETools 3.1 release

* Mon Oct 30 2006 Dan Walsh <dwalsh@redhat.com> 3.0-2.fc6
- bump for fc6
 
* Thu Oct 26 2006 Dan Walsh <dwalsh@redhat.com> 3.0-2
- Build on rawhide

* Sun Oct 15 2006 Dan Walsh <dwalsh@redhat.com> 3.0-1
- Update to upstream

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - sh: line 0: fg: no job control
- rebuild

* Tue May 23 2006 Dan Walsh <dwalsh@redhat.com> 2.4-2
- Remove sqlite include directory

* Wed May 3 2006 Dan Walsh <dwalsh@redhat.com> 2.4-1
- Update from upstream

* Mon Apr 10 2006 Dan Walsh <dwalsh@redhat.com> 2.3-3
- Fix help
- Add icons

* Tue Mar 21 2006 Dan Walsh <dwalsh@redhat.com> 2.3-2
- Remove console apps for sediff, sediffx and apol

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.3-1.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.3-1.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Tue Jan 31 2006 Dan Walsh <dwalsh@redhat.com> 2.3-1
- Update from upstream
  * apol:
        added new MLS components tab for sensitivities, 
        levels, and categories.
        Changed users tab to support ranges and default 
        levels.
        added range transition tab for searching range
        Transition rules.
        added new tab for network context components.
        added new tab for file system context components.
  * libapol:
        added binpol support for MLS, network contexts, 
        and file system contexts.
  * seinfo:
        added command line options for MLS components.
        added command line options for network contexts
        and file system contexts.
  * sesearch:
        added command line option for searching for rules
        by conditional boolean name.
  * seaudit:
        added new column in the log view for the 'comm' 
        field found in auditd log files.
        added filters for the 'comm' field and 'message'
        field.
  * manpages:
        added manpages for all tools.        



* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcj

* Wed Dec 14 2005 Dan Walsh <dwalsh@redhat.com> 2.2-4
- Fix dessktop files
- Apply fixes from bkyoung

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Thu Nov 3 2005 Dan Walsh <dwalsh@redhat.com> 2.2-3
- Move more gui files out of base into gui 

* Thu Nov 3 2005 Dan Walsh <dwalsh@redhat.com> 2.2-2
- Move sediff from gui to main package

* Thu Nov 3 2005 Dan Walsh <dwalsh@redhat.com> 2.2-1
- Upgrade to upstream version

* Thu Oct 13 2005 Dan Walsh <dwalsh@redhat.com> 2.1.3-1
- Upgrade to upstream version

* Mon Oct 10 2005 Tomas Mraz <tmraz@redhat.com> 2.1.2-3
- use include instead of pam_stack in pam config

* Thu Sep 1 2005 Dan Walsh <dwalsh@redhat.com> 2.1.2-2
- Fix spec file
 
* Thu Sep 1 2005 Dan Walsh <dwalsh@redhat.com> 2.1.2-1
- Upgrade to upstream version
 
* Thu Aug 18 2005 Florian La Roche <laroche@redhat.com>
- do not package debug files into the -devel package

* Wed Aug 17 2005 Jeremy Katz <katzj@redhat.com> - 2.1.1-3
- rebuild against new cairo

* Wed May 25 2005 Dan Walsh <dwalsh@redhat.com> 2.1.1-0
- Upgrade to upstream version

* Mon May 23 2005 Bill Nottingham <notting@redhat.com> 2.1.0-5
- put libraries in the right place (also puts debuginfo in the right
  package)
- add %%defattr for -devel too

* Thu May 12 2005 Dan Walsh <dwalsh@redhat.com> 2.1.0-4
- Move sepcut to gui apps.

* Fri May 6 2005 Dan Walsh <dwalsh@redhat.com> 2.1.0-3
- Fix Missing return code.

* Wed Apr 20 2005 Dan Walsh <dwalsh@redhat.com> 2.1.0-2
- Fix requires line

* Tue Apr 19 2005 Dan Walsh <dwalsh@redhat.com> 2.1.0-1
- Update to latest from tresys

* Tue Apr 5 2005 Dan Walsh <dwalsh@redhat.com> 2.0.0-2
- Fix buildrequires lines in spec file

* Tue Mar 2 2005 Dan Walsh <dwalsh@redhat.com> 2.0.0-1
- Update to latest from tresys

* Mon Nov 29 2004 Dan Walsh <dwalsh@redhat.com> 1.5.1-6
- add FALLBACK=true to /etc/security/console.apps/apol

* Wed Nov 10 2004 Dan Walsh <dwalsh@redhat.com> 1.5.1-3
- Add badtcl patch from Tresys.

* Mon Nov 8 2004 Dan Walsh <dwalsh@redhat.com> 1.5.1-2
- Apply malloc problem patch provided by  Sami Farin 

* Mon Nov 1 2004 Dan Walsh <dwalsh@redhat.com> 1.5.1-1
- Update to latest from Upstream

* Wed Oct 6 2004 Dan Walsh <dwalsh@redhat.com> 1.4.1-5
- Update tresys patch

* Mon Oct 4 2004 Dan Walsh <dwalsh@redhat.com> 1.4.1-4
- Fix directory ownership

* Thu Jul 8 2004 Dan Walsh <dwalsh@redhat.com> 1.4.1-1
- Latest from Tresys

* Wed Jun 23 2004 Dan Walsh <dwalsh@redhat.com> 1.4-5
- Add build requires libselinux

* Tue Jun 22 2004 Dan Walsh <dwalsh@redhat.com> 1.4-4
- Add support for policy.18

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Jun 10 2004 Dan Walsh <dwalsh@redhat.com> 1.4-2
- Fix install locations of policy_src_dir

* Wed Jun 2 2004 Dan Walsh <dwalsh@redhat.com> 1.4-1
- Update to latest from TRESYS.

* Tue Jun 1 2004 Dan Walsh <dwalsh@redhat.com> 1.3-3
- Make changes to work with targeted/strict policy
* Fri Apr 16 2004 Dan Walsh <dwalsh@redhat.com> 1.3-2
- Take out requirement for policy file

* Fri Apr 16 2004 Dan Walsh <dwalsh@redhat.com> 1.3-1
- Fix doc location

* Fri Apr 16 2004 Dan Walsh <dwalsh@redhat.com> 1.3-1
- Latest from TRESYS

* Tue Apr 13 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-8
- fix location of policy.conf file

* Tue Apr 6 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-7
- Obsolete setools-devel
* Tue Apr 6 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-6
- Fix location of 
* Tue Apr 6 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-5
- Remove devel libraries
- Fix installdir for lib64

* Sat Apr 3 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-4
- Add usr_t file read to policy

* Thu Mar 25 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-3
- Use tcl8.4

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 6 2004 Dan Walsh <dwalsh@redhat.com> 1.2.1-1
- New patch

* Fri Feb 6 2004 Dan Walsh <dwalsh@redhat.com> 1.2-1
- Latest upstream version

* Tue Dec 30 2003 Dan Walsh <dwalsh@redhat.com> 1.1.1-1
- New version from upstream
- Remove seuser.te.  Now in policy file.

* Tue Dec 30 2003 Dan Walsh <dwalsh@redhat.com> 1.1-2
- Add Defattr to devel
- move libs to base kit

* Fri Dec 19 2003 Dan Walsh <dwalsh@redhat.com> 1.1-1
- Update to latest code from tresys
- Break into three separate packages for cmdline, devel and gui
- Incorporate the tcl patch

* Mon Dec 15 2003 Jens Petersen <petersen@redhat.com> - 1.0.1-3
- apply setools-1.0.1-tcltk.patch to build against tcl/tk 8.4
- buildrequire tk-devel

* Thu Nov 20 2003 Dan Walsh <dwalsh@redhat.com> 1.0.1-2
- Add Bwidgets to this RPM

* Tue Nov 4 2003 Dan Walsh <dwalsh@redhat.com> 1.0.1-1
- Upgrade to 1.0.1

* Wed Oct 15 2003 Dan Walsh <dwalsh@redhat.com> 1.0-6
- Clean up build

* Tue Oct 14 2003 Dan Walsh <dwalsh@redhat.com> 1.0-5
- Update with correct seuser.te

* Wed Oct 1 2003 Dan Walsh <dwalsh@redhat.com> 1.0-4
- Update with final release from Tresys

* Mon Jun 2 2003 Dan Walsh <dwalsh@redhat.com> 1.0-1
- Initial version
